@@ -3,4 +3,4 @@ set -ex
 cd src/tests/acceptance_tests/javascript
 npm install
 cd ../..
-pytest
+pytest -k "not language_support"
